==> istio-model-v1alpha3-6.8.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/LoadBalancerSettingsSimpleFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class LoadBalancerSettingsSimpleFluent<A extends LoadBalancerSettingsSimpleFluent<A>> extends BaseFluent<A>{
  public LoadBalancerSettingsSimpleFluent() {
  }
  public LoadBalancerSettingsSimpleFluent(LoadBalancerSettingsSimple instance) {
    instance = (instance != null ? instance : new LoadBalancerSettingsSimple());

    if (instance != null) {
      this.withSimple(instance.getSimple());
      this.withSimple(instance.getSimple());
    }
  }
  private LoadBalancerSettingsSimpleLB simple;
  public LoadBalancerSettingsSimpleLB getSimple() {
    return this.simple;
  }
  public A withSimple(LoadBalancerSettingsSimpleLB simple) {
    this.simple=simple; return (A) this;
  }
  public boolean hasSimple() {
    return this.simple != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LoadBalancerSettingsSimpleFluent that = (LoadBalancerSettingsSimpleFluent) o;
    if (!java.util.Objects.equals(simple, that.simple)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(simple,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (simple != null) { sb.append("simple:"); sb.append(simple); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> istio-model-v1alpha3-6.9.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/LoadBalancerSettingsSimpleFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class LoadBalancerSettingsSimpleFluent<A extends LoadBalancerSettingsSimpleFluent<A>> extends BaseFluent<A>{
  public LoadBalancerSettingsSimpleFluent() {
  }
  
  public LoadBalancerSettingsSimpleFluent(LoadBalancerSettingsSimple instance) {
    this.copyInstance(instance);
  }
  private LoadBalancerSettingsSimpleLB simple;
  
  protected void copyInstance(LoadBalancerSettingsSimple instance) {
    instance = (instance != null ? instance : new LoadBalancerSettingsSimple());
  
    if (instance != null) {
        this.withSimple(instance.getSimple());
        this.withSimple(instance.getSimple());
      }
  }
  
  public LoadBalancerSettingsSimpleLB getSimple() {
    return this.simple;
  }
  
  public A withSimple(LoadBalancerSettingsSimpleLB simple) {
    this.simple=simple; return (A) this;
  }
  
  public boolean hasSimple() {
    return this.simple != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LoadBalancerSettingsSimpleFluent that = (LoadBalancerSettingsSimpleFluent) o;
    if (!java.util.Objects.equals(simple, that.simple)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(simple,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (simple != null) { sb.append("simple:"); sb.append(simple); }
    sb.append("}");
    return sb.toString();
  }
  

}
